# WARNING: This package is synchronized with Fedora!

%define major 4
%define libname %mklibname %name %major
%define libname_devel %mklibname -d %name

%global btrfs_version 3.16.2
%global util_linux_version 2.24

Name:		snapper
Version:	0.4.1
Release:	%mkrel 1
License:	GPLv2
Group:		File tools
BuildRequires:	boost-devel
BuildRequires:	gettext
BuildRequires:	libtool
BuildRequires:	libxml2-devel
BuildRequires:	dbus-devel
BuildRequires:	pam-devel
BuildRequires:	libxslt-devel
BuildRequires:	xsltproc
BuildRequires:	docbook-style-xsl
BuildRequires:	libacl-devel
BuildRequires:	btrfs-devel >= %{btrfs_version}
BuildRequires:	libmount-devel >= %{util_linux_version}
BuildRequires:	e2fsprogs-devel

Requires:	%{libname}%{?_isa} = %{version}-%{release}
Requires:	diffutils
Summary:	Tool for filesystem snapshot management
Url:		http://en.opensuse.org/Portal:Snapper

Source0:	http://ftp.suse.com/pub/projects/snapper/%{name}-%{version}.tar.bz2

# Patches from Fedora
Patch0:		%{name}-remove-ext4-info-xml.patch
Patch1:		%{name}-securelibdir.patch

%description
This package contains snapper, a tool for filesystem snapshot management.

%package -n %{libname}
Summary:	Library for filesystem snapshot management
Group:		System/Libraries
Requires:	util-linux >= %{util_linux_version}
Requires:	btrfs-progs >= %{btrfs_version}

%description -n %{libname}
This package contains the snapper shared library
for filesystem snapshot management.

%package -n %{libname_devel}
Group:		Development/C
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{name} = %{version}-%{release}
Requires:	libstdc++-devel
Requires:	boost-devel
Requires:	libxml2-devel
Requires:	libmount-devel >= %{util_linux_version}
Summary:	Header files and documentation for libsnapper

%description -n %{libname_devel}
This package contains header files and documentation for developing with
snapper.

%package -n pam_%{name}
Requires:	%{name} = %version-%{release}
Requires:	pam
Summary:	PAM module for calling snapper
Group:		System/Libraries

%description -n pam_%{name}
A PAM module for calling snapper during user login and logout.

%prep
%autosetup -p1
# use libexecdir
find -type f -exec sed -i -e "s|/usr/lib/snapper|%{_libexecdir}/%{name}|g" {} ';'

%build
# NOTE: This needed for regenerating the configuration to include changes from patches
aclocal
libtoolize --force --automake --copy
autoheader
automake --add-missing --copy
autoconf

# NOTE: --disable-ext4 option removes support for ext4 internal snapshots since the feature
# never made it into upstream kernel
%configure2_5x --disable-silent-rules --disable-ext4 --disable-zypp
#NOTE: avoid 'unused-direct-shlib-dependency' warning in rpmlint checks
sed -i -e 's! -shared ! -Wl,--as-needed\0!g' libtool
%make_build

%install
%make_install
install -m644 -D data/sysconfig.snapper %{buildroot}%{_sysconfdir}/sysconfig/%{name}
%{find_lang} %{name}
rm -f %{buildroot}/%{_libdir}/*.la
rm -f %{buildroot}/%{_libdir}/security/*.la
rm -rf %{buildroot}/%{_sysconfdir}/cron.hourly
rm -rf %{buildroot}/%{_sysconfdir}/cron.daily
rm -rf %{buildroot}/%{_docdir}/%{name}/COPYING

%files -f %{name}.lang
%license COPYING
%doc AUTHORS
%{_bindir}/snapper
%{_sbindir}/mksubvolume
%{_sbindir}/snapperd
%config(noreplace) %{_sysconfdir}/logrotate.d/snapper
%{_unitdir}/%{name}-*.timer
%{_unitdir}/%{name}-*.service
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.opensuse.Snapper.conf
%{_datadir}/dbus-1/system-services/org.opensuse.Snapper.service
%{_mandir}/man8/%{name}.8*
%{_mandir}/man8/mksubvolume.8*
%{_mandir}/man8/snapperd.8*
%{_mandir}/man5/snapper-configs.5*
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/installation-helper
%{_libexecdir}/%{name}/systemd-helper

%files -n %{libname}
%license COPYING
%{_libdir}/libsnapper.so.%{major}
%{_libdir}/libsnapper.so.%{major}.*
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/configs
%dir %{_sysconfdir}/%{name}/config-templates
%config(noreplace) %{_sysconfdir}/%{name}/config-templates/default
%dir %{_sysconfdir}/%{name}/filters
%config(noreplace) %{_sysconfdir}/%{name}/filters/*.txt
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}

%files -n %{libname_devel}
%doc examples/c/*.c
%doc examples/c++-lib/*.cc
%{_libdir}/libsnapper.so
%{_includedir}/%{name}

%files -n pam_%{name}
%{_libdir}/security/pam_snapper.so
%dir %{_prefix}/lib/pam_snapper
%{_prefix}/lib/pam_snapper/*.sh
%doc %{_mandir}/*/pam_snapper*.*



%changelog
* Thu Mar 23 2017 ngompa <ngompa> 0.4.1-1.mga6
+ Revision: 1094584
- Update to 0.4.1
- Use proper libexec dir for helper binaries

* Sun Sep 25 2016 ngompa <ngompa> 0.3.3-1.mga6
+ Revision: 1055954
- Upgrade to 0.3.3

* Wed Feb 17 2016 umeabot <umeabot> 0.2.8-5.mga6
+ Revision: 962862
- Mageia 6 Mass Rebuild

* Sun Dec 27 2015 daviddavid <daviddavid> 0.2.8-4.mga6
+ Revision: 916100
- rebuild for new boost 1.60.0

* Wed Nov 18 2015 ngompa <ngompa> 0.2.8-3.mga6
+ Revision: 903974
- Add patch for cleanup.service to use libexecdir

* Mon Nov 16 2015 ngompa <ngompa> 0.2.8-2.mga6
+ Revision: 903484
- Import snapper into Mageia

